Settlement

Type Alias Settlement 

pub type Settlement = Outcome;
The lifecycle conclusion applied to a claim, currently a fulfilled or breached Outcome.

Aliased Type

pub enum Settlement {
    Fulfilled,
    Breached,
}

Variants



Fulfilled

The pact was fulfilled successfully.



Breached

The pact could not be fulfilled and must be breached.